#' Upload telemetry to a Thingsboard platform
#'
#' @param URL Thingsboard API URL (See https://thingsboard.io/docs/reference/http-api/#telemetry-upload-api).
#' @param dfData Time series provided by the `Data` item returned by \code{[SGL_GrabAllVariables]}
#'
#' @export
#'
#' @importFrom jsonlite toJSON
#' @importFrom httr POST
#'
#' @examples
#' \dontrun{
#' thingsboard_UploadTelemetry(
#'   "http://domain.com/api/v1/my_access_token/telemetry",
#'   SGL_GrabAllVariables()$Data
#' )
#' }
thingsboard_UploadTelemetry <- function(URL, dfData) {
  dfData$datetime <- paste0(format(as.numeric(as.POSIXct(dfData$datetime))), "000")
  lData <- split(dfData, dfData$datetime)
  lapply(X = lData, FUN = thingsboard_UploadTimeStep, URL)
}

thingsboard_UploadTimeStep <- function(x, URL) {
  ts <- x$datetime[1]
  lJSON <- list(ts = ts, values = as.list(x$value))
  names(lJSON$values) <- x$id
  sJSON <- jsonlite::toJSON(lJSON, auto_unbox = TRUE)
  httr::POST(url = URL, body = sJSON, encode = "raw")
}
